#error span {
  display: none;
}

#error #js {
  display: inline;
}

#network-controls #jsc-login {
  display: none;
  clear:both;
}

#network-controls #jsc-login .jsc-login-label {
  float: left;
  width: 230px;
  height:23px;
}

#encapsulate #ws {
  display: none;
}

#encapsulate #reg {
  display: none;
}

#encapsulate #reg #de-reg-button {
  display: none;
}

#dest {
  float:left;
}

#dialing-actions {
  float:right;
}

#session-controls {
  display: none;
}

#video-session {
  position: relative;
  top: 0;
  left: 0;
  width: 400px;
  height: 300px;
  padding: 6px;
  border-radius: 10px;
  border: 2px solid #EEE;
  display: none;
}

#video-session video#remoteView {
  width: 400px;
  height: 300px;
  background-color: #000;
}

#video-session video#selfView {
  position: absolute;
  bottom: 6px;
  left: 6px;
  width: 133px;
  height: 100px;
  background-color: #111;
  border-top: 2px solid #CCC;
  border-right: 2px solid #CCC;
  padding: 5px;
}

#network-controls input{
float:right;
}

#jsc-login-button,#ws{
clear:both;
}

#chat {
  padding: 5px;
  clear:both;
  min-height: 70px;
}

.tab-label{
  margin:6px 3px 0 0;
  padding:5px;
  display:block;
  float:left;
  background-color:#C1C1C1;
  border-top-left-radius:4px;
  border-top-right-radius:4px;
  font: -webkit-small-control;
  width: 42px;
  overflow: hidden;
}

#chat > ul {
  padding: 0px;
  margin: 0px;
}

.active-tab {
  background-color:#F0F0F0;
}   

/* adapted from try.jssip.net */

.chatSession {
  display: block;
  float: left;
  background-color:#F0F0F0;
  border-radius: 0 10px 10px 0;
  padding: 5px;
  margin-bottom: 5px;
  width: 338px;
}

.chatSession .close {
  float: right;
  color: darkred;
  font-family: Arial, "Helvetica Neue", Helvetica, sans-serif;
  cursor: pointer;
  margin-right: 4px;
  font-size: 12px;
}

.chatSession .peer span {
  font-size: 12px;
  font-weight: bold;
  color: #555;
}

.chatSession .chat {
  position: relative;
  margin-top: 10px;
}

.chatSession .chat .chatting {
  position: relative;
  background: #FFF;
  padding: 5px;
  font-size: 12px;
  color: #333;
  height: 50px;
  overflow: auto;
  border: 1px solid #CCC;
}

.chatSession .chat .iscomposing {
  position: absolute;
  /* background: url("../images/iscomposing2.gif") no-repeat;*/
  width: 26px;
  height: 26px;
  bottom: 32px;
  right: 16px;
  z-index: 20;
  display: none;
}

.chatSession .chat .chatting p {
  font-size: inherit;
  margin: 0px;
  font-family: sans-serif;
}

.chatSession .chat .chatting p.me {
  color: #444;
}

.chatSession .chat .chatting p.peer {
  color: #008F00;
}

.chatSession .chat .chatting p.error {
  color: red;
}

.chatSession .chat input[type="text"] {
  position: relative;
  margin: 5px 0 0 0;
  display: block;
  line-height: 24px;
  height: 24px;
  border: 1px solid #CCC;
  border-radius: 0 0 5px 0;
  font-size: 12px;
  text-indent: 5px;
  color: #000;
  font-style: normal;
  width: 334px
}

.chatSession .chat input[type="text"].inactive {
  color: #888;
  font-style: italic;
}

/* end of adapted from try.jssip.net */

#new-chat {
  display: block;
  margin-top: 3px;
}

.no-contact {
  color: darkred;
  font-style: italic;
  font-family: sans-serif;
  font-size: 12px;
  display: block;
}



#dtmf-pad input{
  float:left;
  width: 25px;
  margin: 2px;
}

#dtmf-pad br{
  clear:both;
}

#jsc-login-option input{
  float:left;
}

#jsc-login-option {
  clear:both;
}

#encapsulate {
  width: 360px;
  padding: 3px;
}

#call {
  height: 64px;
  padding: 5px;
  clear:both;
}

#error span, #ws span, #reg span {
  font: -webkit-small-control;
  letter-spacing: normal;
}

#header {
  height: 100px;
}

#header h1 {
  font-family: Arial;
  font-weight: normal;
  margin:0;
  display: block;
}

#jsc-logout-button {
  float:right;
  margin: 3px;
}

#welcome {
  display: inline;
}

h3 {
  font-family: Arial;
  font-weight: normal;
  margin:0;
  margin-top: 5px;
}

hr {
  margin:6px;
  margin-bottom: 0px;
}

span {
  font-family: Arial;
  font-size: 14px;
  margin-left: 3px;
}

#peer {
  font-family: Arial;
  font-size: 14px;
  margin-left: 3px;
  display: inline;
  float: left;
}

.red-phone {
  -webkit-transform:rotate(135deg);
  -moz-transform:rotate(135deg);
  -o-transform:rotate(135deg);
  color:red;
}

#lang_selection {
  float:left;
  display: inline;
  margin-bottom: 8px;
}

#jsc-login-option {
  float:right;
}

#communicator {
  clear: both;
  overflow: hidden;
}

#dtmf-pad {
  z-index: 200;
  position: absolute;
  top: 72px;
  left: 244px;
  display: none;
}

#session-actions {
  float: right;
}

#start-chat {
  float:right;
}

#chat-error, #call-info {
  height: 12px;
  margin-bottom: 4px;
}

#chat-error span, #call-info span{
  display: none;
}

#call-video {
  display: none;
}


